import pandas as pd 
import numpy as np
from sklearn.base import TransformerMixin

# Add BaseEstimator here


def test(x):
    print(x)
    
